"""Solutions for tests."""

from qiskit import ClassicalRegister, QuantumCircuit, QuantumRegister
from qiskit.circuit import CircuitInstruction, Clbit, Instruction, Qubit

from QCut import cut_wire
from QCut.wirecut import CutLocation

qc_1 = QuantumCircuit(4)
qc_1.x(0)
qc_1.cx(0,1)
qc_1.append(cut_wire, [1,2])
qc_1.cx(2,3)

qc_2 = QuantumCircuit(6)
qc_2.x(0)
qc_2.cx(0,1)
qc_2.cx(0,2)
qc_2.append(cut_wire, [1,3])
qc_2.append(cut_wire, [2,4])
qc_2.cx(3,5)
qc_2.cz(4,5)

qc_3 = QuantumCircuit(6)
qc_3.x(0)
qc_3.cx(0,1)
qc_3.append(cut_wire, [1,2])
qc_3.cx(2,3)
qc_3.append(cut_wire, [3,4])
qc_3.cz(4,5)

test_circuits = [qc_1, qc_2, qc_3]

subcircuit_solutions = [
    [
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2248"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2248"), 0), Qubit(QuantumRegister(2, "q2248"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="Meas", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2248"), 1),), clbits=())],
        [CircuitInstruction(operation=Instruction(name="Init", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2249"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2249"), 0), Qubit(QuantumRegister(2, "q2249"), 1)), clbits=())],
    ],
    [
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q2238"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q2238"), 0), Qubit(QuantumRegister(3, "q2238"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="Meas", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q2238"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q2238"), 0), Qubit(QuantumRegister(3, "q2238"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="Meas", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q2238"), 2),), clbits=())],
        [CircuitInstruction(operation=Instruction(name="Init", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q2239"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="Init", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q2239"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q2239"), 0), Qubit(QuantumRegister(3, "q2239"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q2239"), 1), Qubit(QuantumRegister(3, "q2239"), 2)), clbits=())],
    ],
    [
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2240"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2240"), 0), Qubit(QuantumRegister(2, "q2240"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="Meas", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2240"), 1),), clbits=())],
        [CircuitInstruction(operation=Instruction(name="Init", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2241"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2241"), 0), Qubit(QuantumRegister(2, "q2241"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="Meas", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2241"), 1),), clbits=())],
        [CircuitInstruction(operation=Instruction(name="Init", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2242"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2242"), 0), Qubit(QuantumRegister(2, "q2242"), 1)), clbits=())],
    ],
]
cut_location_solutions = [[CutLocation((((QuantumRegister(4, "q"), 1), (QuantumRegister(4, "q"), 2)), 2))],
                          [CutLocation((((QuantumRegister(6, "q"), 1), (QuantumRegister(6, "q"), 3)), 3)), CutLocation((((QuantumRegister(6, "q"), 2), (QuantumRegister(6, "q"), 4)), 3))],
                          [CutLocation((((QuantumRegister(6, "q"), 1), (QuantumRegister(6, "q"), 2)), 2)), CutLocation((((QuantumRegister(6, "q"), 3), (QuantumRegister(6, "q"), 4)), 3))],
                          ]

bounds_solutions = [[1], [2], [1, 3]]

coefs_solutions = [
    [1, 1, 1, -1, 1, -1, 1, -1],
    [1, 1, 1, -1, 1, -1, 1, -1, 1, 1, 1, -1, 1, -1, 1, -1, 1, 1, 1, -1, 1, -1, 1, -1, -1, -1, -1, 1, -1, 1, -1, 1, 1, 1, 1, -1, 1, -1, 1, -1, -1, -1, -1, 1, -1, 1, -1, 1, 1, 1, 1, -1, 1, -1, 1, -1, -1, -1, -1, 1, -1, 1, -1, 1],
    [1, 1, 1, -1, 1, -1, 1, -1, 1, 1, 1, -1, 1, -1, 1, -1, 1, 1, 1, -1, 1, -1, 1, -1, -1, -1, -1, 1, -1, 1, -1, 1, 1, 1, 1, -1, 1, -1, 1, -1, -1, -1, -1, 1, -1, 1, -1, 1, 1, 1, 1, -1, 1, -1, 1, -1, -1, -1, -1, 1, -1, 1, -1, 1],
]

id_meas_solutions = [
    [[0, 0, 0], [1, 0, 0]],
    [[0, 0, 0], [0, 0, 1], [1, 0, 0], [1, 0, 1], [2, 0, 0], [3, 0, 0], [4, 0, 0], [5, 0, 0], [6, 0, 0], [7, 0, 0], [8, 0, 0], [8, 0, 1], [9, 0, 0], [9, 0, 1], [10, 0, 0], [11, 0, 0], [12, 0, 0], [13, 0, 0], [14, 0, 0], [15, 0, 0], [16, 0, 1], [17, 0, 1], [24, 0, 1], [25, 0, 1], [32, 0, 1], [33, 0, 1], [40, 0, 1], [41, 0, 1], [48, 0, 1], [49, 0, 1], [56, 0, 1], [57, 0, 1]],
    [[0, 0, 0], [0, 1, 0], [1, 0, 0], [1, 1, 0], [2, 0, 0], [3, 0, 0], [4, 0, 0], [5, 0, 0], [6, 0, 0], [7, 0, 0], [8, 0, 0], [8, 1, 0], [9, 0, 0], [9, 1, 0], [10, 0, 0], [11, 0, 0], [12, 0, 0], [13, 0, 0], [14, 0, 0], [15, 0, 0], [16, 1, 0], [17, 1, 0], [24, 1, 0], [25, 1, 0], [32, 1, 0], [33, 1, 0], [40, 1, 0], [41, 1, 0], [48, 1, 0], [49, 1, 0], [56, 1, 0], [57, 1, 0]],
]

test_observables = [
    [0,1,2, [0,2], [1,2], [0,1,2]], [0,1,2,3, [0,3], [1,2,3], [0,1,2,3]], [0,1,2,3, [0,3], [1,2,3], [0,1,2,3]],
]

exp_val_solutions = [
    [-1.0, -1.0, -1.0, 1.0, 1.0, -1.0], [-1.0, -1.0, -1.0, -1.0, 1.0, -1.0, 1.0], [1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0],
]

experiment_circuit_solutions = [
    [
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0), Qubit(QuantumRegister(2, "q2515"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0), Qubit(QuantumRegister(2, "q2516"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0), Qubit(QuantumRegister(2, "q2515"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0), Qubit(QuantumRegister(2, "q2516"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0), Qubit(QuantumRegister(2, "q2515"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0), Qubit(QuantumRegister(2, "q2516"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0), Qubit(QuantumRegister(2, "q2515"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0), Qubit(QuantumRegister(2, "q2516"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0), Qubit(QuantumRegister(2, "q2515"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0), Qubit(QuantumRegister(2, "q2516"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0), Qubit(QuantumRegister(2, "q2515"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0), Qubit(QuantumRegister(2, "q2516"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0), Qubit(QuantumRegister(2, "q2515"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0), Qubit(QuantumRegister(2, "q2516"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0), Qubit(QuantumRegister(2, "q2515"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2515"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0), Qubit(QuantumRegister(2, "q2516"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2516"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
    ],
    [
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0), Qubit(QuantumRegister(3, "q1662"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 1),), clbits=(Clbit(ClassicalRegister(2, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 2),), clbits=(Clbit(ClassicalRegister(2, "c"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1662"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1), Qubit(QuantumRegister(3, "q1663"), 2)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 0),), clbits=(Clbit(ClassicalRegister(3, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 1),), clbits=(Clbit(ClassicalRegister(3, "meas"), 1),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(3, "q1663"), 2),), clbits=(Clbit(ClassicalRegister(3, "meas"), 2),))] ,
    ],
    [
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="sdg", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="h", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="z", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="s", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0), Qubit(QuantumRegister(2, "q2520"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2520"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cx", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0), Qubit(QuantumRegister(2, "q2521"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 1),), clbits=(Clbit(ClassicalRegister(1, "c"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2521"), 0),), clbits=(Clbit(ClassicalRegister(1, "meas"), 0),))] ,
        [CircuitInstruction(operation=Instruction(name="x", num_qubits=1, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=()), CircuitInstruction(operation=Instruction(name="cz", num_qubits=2, num_clbits=0, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0), Qubit(QuantumRegister(2, "q2522"), 1)), clbits=()), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 0),), clbits=(Clbit(ClassicalRegister(2, "meas"), 0),)), CircuitInstruction(operation=Instruction(name="measure", num_qubits=1, num_clbits=1, params=[]), qubits=(Qubit(QuantumRegister(2, "q2522"), 1),), clbits=(Clbit(ClassicalRegister(2, "meas"), 1),))] ,
    ],

]
